@@ -177,7 +177,7 @@ def _parse_vaccines_supplied_by_manufacturer(
             raise Exception("Missing manufacturer!")
         return manu_keys[num]
 
-    r_list = [None, 1, 2, 6]
+    r_list = [None, 1, 2, 4, 6]
 
     date = None
     manufacturer = None
@@ -216,6 +216,13 @@ def _parse_vaccines_supplied_by_manufacturer(
             setattr(manu_row, "date", date)
             setattr(manu_row, manufacturer, value)
 
+        if R == 4:
+            # same value as previous, but different manufacturer
+            date = parse_date(C[0])
+            manufacturer = get_manufacturer((C[1]))
+            setattr(manu_row, "date", date)
+            setattr(manu_row, manufacturer, value) # reuse value from previous iteration
+
         if R == 6:
             # same manufacturer and value as previous
             date = parse_date(C[0])
@@ -345,23 +352,12 @@ def _parse_vaccinations_by_municipalities_share(data) -> "list[VaccinationMunSha
     for el in resp:
         C = el["C"]
         R = el.get("R", None)
-        if len(C) == 6:
-            name, population, share2, share1, dose1, dose2 = el["C"]
-
-        elif len(C) == 5:
-            if R == 32:
-                name, population, share2, share1, dose1 = el["C"]
-                dose2 = int(population * float(share2))
-            elif R == 16:
-                name, population, share2, share1, dose2 = el["C"]
-                dose1 = int(population * float(share1))
-            elif R == 4:
-                name, population, share1, dose1, dose2 = el["C"]
-                share2 = dose2 / population
-            else:
-                print(el)
-                raise Exception(f"Unknown R: {R}")
-
+        dose1 = None
+        dose2 = None
+        if len(C) == 4:
+            name, share1, share2, population = C
+            dose1 = round(population * float(share1))
+            dose2 = round(population * float(share2))
         else:
             print(el)
             raise Exception(f"Unknown C length: {len(C)}")
@@ -635,3 +631,9 @@ def _parse_vaccinations_date_range_manufacturers_used(data):
 
         parsed_data.append(result)
     return parsed_data
+
+
+def _parse_single_data(data):
+    _validate_response_data(data)
+    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
+    return resp[0]["M0"]
