@@ -32,8 +32,8 @@ class CepimoseTestCase(unittest.TestCase):
         #! NIJZ is changing data tests could fail in the future
         assertRow(data[9], datetime.datetime(2021, 1, 5), 15711, 0)
         assertRow(data[22], datetime.datetime(2021, 1, 18), 49100, 315)
-        assertRow(data[41], datetime.datetime(2021, 2, 6), 56066, 44924)
-        assertRow(data[42], datetime.datetime(2021, 2, 7), 56066, 44924)
+        assertRow(data[41], datetime.datetime(2021, 2, 6), 56066, 45339)
+        assertRow(data[42], datetime.datetime(2021, 2, 7), 56066, 45339)
 
         # values should be growing
         firstPrevious = 0
@@ -173,6 +173,9 @@ class CepimoseTestCase(unittest.TestCase):
             self.assertGreaterEqual(1, m.share1)
             self.assertGreaterEqual(1, m.share2)
 
+            self.assertAlmostEqual(m.dose1, m.population * float(m.share1), delta=0.00001)
+            self.assertAlmostEqual(m.dose2, m.population * float(m.share2), delta=0.00001)
+
     def test_vaccination_timestamp(self):
         ts = cepimose.vaccinations_timestamp()
         print("Last update:", ts)
@@ -253,10 +256,10 @@ class CepimoseTestCase(unittest.TestCase):
         assertRow(data[38], datetime.datetime(2021, 2, 3), [4805, None, 1, None])
         assertRow(data[42], datetime.datetime(2021, 2, 7), [None, None, None, None])
         assertRow(data[50], datetime.datetime(2021, 2, 15), [28, 40, 18, None])
-        assertRow(data[79], datetime.datetime(2021, 3, 16), [606, 445, None, None])
+        assertRow(data[79], datetime.datetime(2021, 3, 16), [603, 445, 12, None])
         assertRow(data[98], datetime.datetime(2021, 4, 4), [None, 1594, None, None])
         assertRow(data[99], datetime.datetime(2021, 4, 5), [1, None, None, None])
-        assertRow(data[120], datetime.datetime(2021, 4, 26), [None, None, 385, None])
+        assertRow(data[120], datetime.datetime(2021, 4, 26), [1, None, 381, None])
         assertRow(data[134], datetime.datetime(2021, 5, 10), [46, 141, 2080, 717])
 
         for row in data:
